package com.anthonycicchetti.slackbot

import org.junit.jupiter.api.Test

import org.junit.jupiter.api.Assertions.*

internal class TransformationsTest {

    @Test
    fun `One lowercase word gets properly converted`() {
        val actual = "testing"
        val expected = "tEsTiNg"

        assertEquals(expected, actual.toSpongemock())
    }

    @Test
    fun `An ALL-CAPS word gets properly converted`() {
        val actual = "MAGMORTAR"
        val expected = "mAgMoRtAr"

        assertEquals(expected, actual.toSpongemock())
    }

    @Test
    fun `A title-cased word gets properly converted`() {
        val actual = "Electivire"
        val expected = "eLeCtIvIrE"

        assertEquals(expected, actual.toSpongemock())
    }

    @Test
    fun `Multiple lowercase words get properly converted`() {
        val actual = "raichu and charmeleon"
        val expected = "rAiChU aNd cHaRmElEoN"

        assertEquals(expected, actual.toSpongemock())
    }

    @Test
    fun `Multiple lowercase words with numbers interspersed get properly converted`() {
        val actual = "6 fearow cannot possibly defeat 2 dragonite"
        val expected = "6 fEaRoW cAnNoT pOsSiBlY dEfEaT 2 dRaGoNiTe"

        assertEquals(expected, actual.toSpongemock())
    }

    @Test
    fun `Multiple Title-Case words get properly converted`() {
        val actual = "Harry Potter And The Prisoner Of Azkaban"
        val expected = "hArRy pOtTeR aNd tHe pRiSoNeR oF aZkAbAn"

        assertEquals(expected, actual.toSpongemock())
    }

    @Test
    fun `Multiple ALL-CAPS words get properly converted`() {
        val actual = "I WISH YOU WEREN'T MY DAD"
        // TODO: Probably a compelling argument that I should not be interacting with punctuation...
        val expected = "i wIsH yOu wErEn't mY dAd"

        assertEquals(expected, actual.toSpongemock())
    }
}